@@ -50,7 +50,7 @@ class LatexEntry : public WorksheetEntry
 
     void interruptEvaluation();
 
-    void layOutForWidth(double w, bool force = false);
+    void layOutForWidth(qreal w, bool force = false);
 
     int searchText(QString text, QString pattern,
                    QTextDocument::FindFlags qt_flags);
